@@ -1,8 +1,10 @@
 import contextlib
+import os
 from collections.abc import Mapping  # noqa
 
 import dask
 import dask.array as da
+import distributed
 import packaging.version
 import pandas
 import sklearn
@@ -11,10 +13,15 @@ import sklearn.utils.validation
 SK_VERSION = packaging.version.parse(sklearn.__version__)
 DASK_VERSION = packaging.version.parse(dask.__version__)
 PANDAS_VERSION = packaging.version.parse(pandas.__version__)
+DISTRIBUTED_VERSION = packaging.version.parse(distributed.__version__)
 
 SK_022 = SK_VERSION >= packaging.version.parse("0.22")
 SK_0221 = SK_VERSION >= packaging.version.parse("0.22.1")
 DASK_240 = DASK_VERSION >= packaging.version.parse("2.4.0")
+DASK_2130 = DASK_VERSION >= packaging.version.parse("2.13.0")
+DISTRIBUTED_2_5_0 = DISTRIBUTED_VERSION > packaging.version.parse("2.5.0")
+DISTRIBUTED_2_11_0 = DISTRIBUTED_VERSION > packaging.version.parse("2.10.0")  # dev
+WINDOWS = os.name == "nt"
 
 
 @contextlib.contextmanager
